@@ -36,22 +36,3 @@ function( x, pch=c( 1, 3 ), col=c( 2, 8 ), cex=c( 1, 1 ), ask = TRUE, ... ){
 	invisible()
 }
 
-test.plot.predict.mex <- function(){
-# check reproduce Figure 6 in Heffernan and Tawn
-  w <- mex(winter,mqu=0.7,penalty="none", which="NO", dqu=.7, margins="gumbel", constrain=FALSE)
-  noMod <- bootmex(w)
-  noPred <- predict(noMod)
-  par(mfcol=c(2,2))
-  res <- plot(noPred,main="Fig. 6 Heffernan and Tawn (2004)")
-  checkEquals(res, NULL, msg="plot.predict.mex: correct execution")
-
-# check for 2-d data
-  R <- 20
-  nsim <- 100
-  wavesurge.mex <- mex(wavesurge,mqu=.7,which=1, margins="laplace")
-  wavesurge.boot <- bootmex(wavesurge.mex,R=R)
-  wavesurge.pred <- predict(wavesurge.boot,nsim=nsim)
-  par(mfrow=c(1,1))
-  res <- plot(wavesurge.pred)
-  checkEquals(res, NULL, msg="plot.predict.mex: correct execution")
-}
